@@ -22,7 +22,11 @@ class ElasticsearchPool(BaseConnectionPool):
                 elasticsearch = importlib.import_module("elasticsearch")
             except ImportError:
                 raise Exception(f"elasticsearch is not exist,run:pip install elasticsearch==7.15.2")
-            pool = elasticsearch.AsyncElasticsearch(hosts=hosts)
+            params = info.params
+            if not params:
+                pool = elasticsearch.AsyncElasticsearch(hosts=hosts)
+            else:
+                pool = elasticsearch.AsyncElasticsearch(hosts=hosts, **params)
             return pool
         else:
             raise NotImplementedError
@@ -35,5 +39,9 @@ class ElasticsearchPool(BaseConnectionPool):
             elasticsearch = importlib.import_module("elasticsearch")
         except ImportError:
             raise Exception(f"elasticsearch is not exist,run:pip install elasticsearch==7.15.2")
-        pool = elasticsearch.Elasticsearch(hosts)
+        params = info.params
+        if not params:
+            pool = elasticsearch.Elasticsearch(hosts)
+        else:
+            pool = elasticsearch.Elasticsearch(hosts, **params)
         return pool
