@@ -21,7 +21,12 @@ def Cache(ex=3600 * 8, cache_key=None):
         # 默认key生成方法：str(item)
         @functools.wraps(func)
         def cache_wrapper(*args, **params):
-            return deal_cache(func, ex, cache_key, *args, **params)
+            try:
+                data = deal_cache(func, ex, cache_key, *args, **params)
+            except Exception as e:
+                logging.error(traceback.format_exc())
+                data = func(*args, **params)
+            return data
 
         return cache_wrapper
 
